@@ -3,9 +3,10 @@
  * PySilc - Python SILC Toolkit Bindings
  *
  * Copyright (c) 2006, Alastair Tse <alastair@liquidx.net>
+ * Copyright (c) 2007, Martynas Venckus <martynas@altroot.org>
  * All rights reserved.
  *
- * This program is free software; you can redistributed it and/or modify 
+ * This program is free software; you can redistributed it and/or modify
  * it under the terms of the BSD License. See LICENSE in the distribution
  * for details or http://www.liquidx.net/pysilc/.
  *
@@ -22,7 +23,7 @@
 #endif
 
 #include "pysilc_macros.h"
-#include <silcincludes.h>
+#include <silc.h>
 #include <silcclient.h>
 #include <silctypes.h>
 
@@ -40,18 +41,17 @@ typedef struct {
 
 typedef struct {
     PyObject_HEAD
-    SilcPKCS        pkcs;
     SilcPublicKey   public;
     SilcPrivateKey  private;
 } PySilcKeys;
 
 typedef struct {
     PyObject_HEAD
-    
+
     // members that are callable objects
     PyObject *say, *channel_message, *private_message,  *command;
     PyObject *connected, *disconnected;
-        
+
     PyObject *notify_none;
     PyObject *notify_invite;
     PyObject *notify_join;
@@ -95,21 +95,23 @@ typedef struct {
     PyObject *command_reply_service;
 
     PyObject *command_reply_failed; // custom handler
-    
+
     PySilcKeys *keys;
-    
-    // TODO: not used 
-    PyObject *get_auth_method, 
-        *verify_public_key, 
-        *ask_passphrase, 
-        *failure, 
+
+    // TODO: not used
+    PyObject *get_auth_method,
+        *verify_public_key,
+        *ask_passphrase,
+        *failure,
         *key_agreement,
         *ftp,
         *detach;
 
-    SilcClient             silcobj;
-    SilcClientConnection   silcconn;
-    SilcClientOperations   callbacks;
+    SilcClient                   silcobj;
+    SilcClientConnection         silcconn;
+    SilcClientConnectCallback    conncallback;
+    SilcClientOperations         callbacks;
+    SilcClientConnectionParams   params;
 
 } PySilcClient;
 
@@ -120,9 +122,9 @@ static PyObject *pysilc_load_key_pair(PyObject *mod, PyObject *args, PyObject *k
 
 static PyMethodDef pysilc_functions[] = {
     {
-        "create_key_pair", 
-        (PyCFunction)pysilc_create_key_pair, 
-        METH_VARARGS|METH_KEYWORDS, 
+        "create_key_pair",
+        (PyCFunction)pysilc_create_key_pair,
+        METH_VARARGS|METH_KEYWORDS,
         "create_key_pair(public_filename, private_filename,\n"
         "                identifier = None, passphrase = \"\"\n"
         "                pkcs_name = None, key_length = 2048)\n\n"
@@ -130,9 +132,9 @@ static PyMethodDef pysilc_functions[] = {
     },
 
     {
-        "load_key_pair", 
-        (PyCFunction)pysilc_load_key_pair, 
-        METH_VARARGS|METH_KEYWORDS, 
+        "load_key_pair",
+        (PyCFunction)pysilc_load_key_pair,
+        METH_VARARGS|METH_KEYWORDS,
         "load_key_pair(public_filename, private_filename, passphrase = \"\")"
         "\n\n"
         "Load a public and private key pair from files with an optional\n"
@@ -140,7 +142,7 @@ static PyMethodDef pysilc_functions[] = {
         "If passphrase is None, then it will be prompted by calling the\n"
         "ask_passphrase callback. If passphrase is an empty string\n"
         "(eg. \"\"), then an empty passphrase will be passed."
-    },    
+    },
 
     {NULL, NULL, 0, NULL},
 };
@@ -157,7 +159,6 @@ static int PySilcChannel_Compare(PyObject *self, PyObject *other);
 
 static PyMethodDef pysilc_channel_methods[] = {
     {NULL, NULL, 0, NULL},
-    
 };
 
 static PyMemberDef pysilc_channel_members[] = {
@@ -182,16 +183,16 @@ static PyMemberDef pysilc_user_members[] = {
 
 /*  ---------------- pysilc keys ------------- */
 
-static PyObject *PySilcKeys_New(SilcPKCS pkcs, SilcPublicKey public, SilcPrivateKey private);
+static PyObject *PySilcKeys_New(SilcPublicKey public, SilcPrivateKey private);
 static void PySilcKeys_Del(PyObject *object);
 
-static PyMethodDef pysilc_keys_methods[] = {
+/*static PyMethodDef pysilc_keys_methods[] = {
     {NULL, NULL, 0, NULL},
-};
+};*/
 
-static PyMemberDef pysilc_keys_members[] = {
+/*static PyMemberDef pysilc_keys_members[] = {
     {NULL, 0, 0, 0, NULL},
-};
+};*/
 
 /*  ---------------- pysilc client ------------- */
 
@@ -208,69 +209,67 @@ static PyObject *pysilc_client_remote_host(PyObject *self);
 static PyObject *pysilc_client_user(PyObject *self);
 
 static PyMethodDef pysilc_client_methods[] = {
-    { 
-        "connect_to_server", 
-        (PyCFunction)pysilc_client_connect_to_server, 
-        METH_VARARGS | METH_KEYWORDS, 
+    {
+        "connect_to_server",
+        (PyCFunction)pysilc_client_connect_to_server,
+        METH_VARARGS | METH_KEYWORDS,
         "connect_to_server(host, port = 706) -> int\n\n"
         "Connect to SILC server. Returns -1 on error."
     },
     {
-        "run_one", 
-        (PyCFunction)pysilc_client_run_one, 
-        METH_NOARGS, 
+        "run_one",
+        (PyCFunction)pysilc_client_run_one,
+        METH_NOARGS,
         "run_one()\n\n"
         "Run one iteration of the run loop."
     },
     {
-        "send_channel_message", 
-        (PyCFunction)pysilc_client_send_channel_message, 
-        METH_VARARGS | METH_KEYWORDS, 
+        "send_channel_message",
+        (PyCFunction)pysilc_client_send_channel_message,
+        METH_VARARGS | METH_KEYWORDS,
         "send_channel_message(channel, messsage, private_key = None,\n"
-        "                     flags = 0, force_send = False)\n\n"
+        "                     flags = 0)\n\n"
         "Send a message (Unicode string) to a channel (SilcChannel object).\n"
-        "Setting 'force_send' to True means send the packet immediately\n."
         "TODO: flags and private_key support not implemented.\n"
     },
     {
-        "send_private_message", 
-        (PyCFunction)pysilc_client_send_private_message, 
-        METH_VARARGS | METH_KEYWORDS, 
+        "send_private_message",
+        (PyCFunction)pysilc_client_send_private_message,
+        METH_VARARGS | METH_KEYWORDS,
         "send_private_message(user, messsage, private_key = None,\n"
-        "                     flags = 0, force_send = False)\n\n"
+        "                     flags = 0)\n\n"
         "Send a message (Unicode string) to a user (SilcUser object).\n"
-        "Setting 'force_send' to True means send the packet immediately\n."
         "TODO: flags and private_key support not implemented.\n"
     },
     {
-        "command_call", 
-        (PyCFunction)pysilc_client_command_call, 
-        METH_VARARGS | METH_KEYWORDS, 
+        "command_call",
+        (PyCFunction)pysilc_client_command_call,
+        METH_VARARGS | METH_KEYWORDS,
         "command_call(string) -> int\n\n"
         "Send a command call to the server and returns the result code of\n"
         "of the command."
     },
     {
-        "set_away_message", 
-        (PyCFunction)pysilc_client_set_away_message, 
-        METH_VARARGS, 
+        "set_away_message",
+        (PyCFunction)pysilc_client_set_away_message,
+        METH_VARARGS,
         "set_away_message(message = None)\n\n"
         "Set away message. If message is None, away status is removed."
-    },    
+    },
     {
-        "remote_host", 
-        (PyCFunction)pysilc_client_remote_host, 
-        METH_NOARGS, 
+        "remote_host",
+        (PyCFunction)pysilc_client_remote_host,
+        METH_NOARGS,
         "remote_host() -> string\n\n"
         "Get remote hostname."
     },
     {
-        "user", 
-        (PyCFunction)pysilc_client_user, 
-        METH_NOARGS, 
+        "user",
+        (PyCFunction)pysilc_client_user,
+        METH_NOARGS,
         "user() -> User\n\n"
         "Get current user."
-    },    
+    },
     {NULL, NULL, 0, NULL},
 };
 
@@ -281,7 +280,7 @@ static PyMemberDef pysilc_client_members[] = {
                           "Callback function when server status needs to be\n"
                           "conveyed to the user. 'message' is a string"),
     PYSILC_MEMBER_OBJ_DEF(PySilcClient, channel_message,
-                          "channel_message(sender, channel, flags, message)" 
+                          "channel_message(sender, channel, flags, message)"
                           "\n\n"
                           "Callback function when client receives a channel\n"
                           "message. 'sender' is type SilcUser,\n"
@@ -397,12 +396,13 @@ static PyMemberDef pysilc_client_members[] = {
 
     PYSILC_MEMBER_OBJ_DEF(PySilcClient, command_reply_failed,
                           "command_reply_failed(command, command_name, status"
-                          ", msg)"),    
+                          ", msg)"),
     {NULL, 0, 0, 0, NULL},
 };
 
 #define PYSILC_CLIENT_DOC  "\
-  SilcClient(keys, nickname = \"\", username = \"\",\n\ realname = \"\",\
+  SilcClient(keys, nickname = \"\", username = \"\",\n\
+             realname = \"\",\
              hostname = \"\")\n\n\
   A SILC Client. 'keys' is a SilcKeys representing a public private\n\
   key pair. 'nickname', 'username', 'realname' and 'hostname'\n\
@@ -432,7 +432,7 @@ static PyTypeObject PySilcClient_Type = {
     0, /* tp_call */
     0, /* tp_str */
     0, /* tp_getattro */
-    0, /* tp_setattro */    
+    0, /* tp_setattro */
     0, /* tp_as_buffer */
     Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
     PYSILC_CLIENT_DOC, /* tp_doc */
@@ -461,8 +461,7 @@ Attributes accessible:\n\n\
   channel_id = string (64-160bit)\n\n\
   mode = int\n\n\
   topic = string\n\n\
-  user_limit = int \n\n\
-  resolve_cmd_ident = int"
+  user_limit = int"
 
 static PyTypeObject PySilcChannel_Type = {
     PyObject_HEAD_INIT(&PyType_Type)
@@ -483,7 +482,7 @@ static PyTypeObject PySilcChannel_Type = {
     0, /* tp_call */
     PySilcChannel_Str, /* tp_str */
     PySilcChannel_GetAttr, /* tp_getattro */
-    0, /* tp_setattro */    
+    0, /* tp_setattro */
     0, /* tp_as_buffer */
     Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
     PYSILC_CHANNEL_DOC, /* tp_doc */
@@ -514,11 +513,8 @@ Accessible Attributes:\n\n\
   server = string\n\n\
   realname = string\n\n\
   fingerprint = string\n\n\
-  fingerprint_len = int\n\n\
   user_id = string (64/160bit)\n\n\
-  mode = int\n\n\
-  status = int\n\n\
-  resolve_cmd_ident = int"
+  mode = int"
 
 static PyTypeObject PySilcUser_Type = {
     PyObject_HEAD_INIT(&PyType_Type)
@@ -539,7 +535,7 @@ static PyTypeObject PySilcUser_Type = {
     0, /* tp_call */
     PySilcUser_Str, /* tp_str */
     PySilcUser_GetAttr, /* tp_getattro */
-    0, /* tp_setattro */    
+    0, /* tp_setattro */
     0, /* tp_as_buffer */
     Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
     PYSILC_USER_DOC, /* tp_doc */
@@ -585,7 +581,7 @@ static PyTypeObject PySilcKeys_Type = {
     0, /* tp_call */
     0, /* tp_str */
     0, /* tp_getattro */
-    0, /* tp_setattro */    
+    0, /* tp_setattro */
     0, /* tp_as_buffer */
     Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
     PYSILC_KEYS_DOC, /* tp_doc */
